#ifndef CREDITSDLG_H
#define CREDITSDLG_H

#include <QtGui/QDialog>

namespace Ui {
    class CreditsDlg;
}

class CreditsDlg : public QDialog {
    Q_OBJECT
    Q_DISABLE_COPY(CreditsDlg)
public:
    //! Constructor.
    explicit CreditsDlg(QWidget *parent = 0);
    //! Destructor.
    virtual ~CreditsDlg();

private:
    Ui::CreditsDlg *m_ui;

private slots:
    void on_closeButton_clicked();
};
#endif // CREDITSDLG_H
